@@ -58,7 +58,7 @@ load(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity,
                }
              w = gif->Image.Width;
              h = gif->Image.Height;
-	     if ((w < 1) || (h < 1) || (w > 8192) || (h > 8192))
+	     if (!IMAGE_DIMENSIONS_OK(w, h))
 	       {
                   DGifCloseFile(gif);
                   return 0;
