@@ -204,19 +204,11 @@ load(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity,
                             xpm_parse_done();
                             return 0;
                          }
-                       if ((w > 8192) || (w < 1))
+                       if (!IMAGE_DIMENSIONS_OK(w, h))
                          {
                             fprintf(stderr,
-                                    "IMLIB ERROR: Image width > 8192 or < 1 pixels for file\n");
-                            free(line);
-                            fclose(f);
-                            xpm_parse_done();
-                            return 0;
-                         }
-                       if ((h > 8192) || (h < 1))
-                         {
-                            fprintf(stderr,
-                                    "IMLIB ERROR: Image height > 8192 or < 1 pixels for file\n");
+                                    "IMLIB ERROR: Invalid image dimension: %dx%d\n",
+                                    w, h);
                             free(line);
                             fclose(f);
                             xpm_parse_done();
@@ -253,8 +245,8 @@ load(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity,
                                  return 0;
                               }
                             ptr = im->data;
-                            end = ptr + (sizeof(DATA32) * w * h);
                             pixels = w * h;
+                            end = ptr + (pixels);
                          }
                        else
                          {
